@@ -38,6 +38,9 @@
 #include <stdlib.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <sys/fcntl.h>
+#include <sys/termios.h>
+#include <dirent.h>
 #include <unistd.h>
 #include <stdio.h>
 #include <string.h>
@@ -796,8 +799,8 @@ anjuta_util_convert_to_utf8 (const gchar *str)
 		if (error != NULL) {
 			g_warning ("g_locale_to_utf8 failed: %s\n", error->message);
 			g_error_free (error);
-			g_free (utf8_msg_string);
-			return NULL;
+			/* g_free (utf8_msg_string);
+			return NULL; */
 		}
 	}
 	return utf8_msg_string;
@@ -1002,11 +1005,7 @@ anjuta_util_get_uri_mime_type (const gchar *uri)
 	return mime_type;
 }
 
-/*
- * Sun specific implementations
- *
- */
-#ifdef sun
+#ifndef HAVE_LIBUTIL
 #include <grp.h>
 
 static int ptym_open (char *pts_name);
@@ -1298,9 +1297,4 @@ int scandir(const char *dir, struct dirent ***namelist,
   return(i);
 }
 
-int alphasort (const struct dirent **a, const struct dirent **b)
-{
-    return (strcmp((*a)->d_name, (*b)->d_name));
-}
-
-#endif /* sun */
+#endif /* HAVE_LIBUTIL */
