@@ -46,9 +46,13 @@
 #define PREF_INDICATORS_AUTOMATIC "indicators.automatic"
 #define PREF_INSTALL_ROOT "build.install.root"
 #define PREF_INSTALL_ROOT_COMMAND "build.install.root.command"
+#define PREF_USE_SB "build.use_scratchbox"
+#define PREF_SB_PATH "build.scratchbox.path"
 
 #define CHECK_BUTTON "preferences_toggle:bool:0:0:build.install.root"
 #define ENTRY "preferences_entry:text:sudo:0:build.install.root.command"
+#define SB_CHECK "preferences_toggle:bool:0:0:build.use_scratchbox"
+#define SB_ENTRY "preferences_entry:text:/scratchbox:0:build.scratchbox.path"
 
 static gpointer parent_class;
 
@@ -83,6 +87,10 @@ typedef struct
 	GHashTable *indicators_updated_editors;
 } BuildContext;
 
+/* Declarations */
+static void update_project_ui (BasicAutotoolsPlugin *bb_plugin);
+static gboolean directory_has_file (const gchar *dirname, const gchar *filename);
+
 static GList *patterns_list = NULL;
 
 /* Allow installation as root (#321455) */
@@ -92,6 +100,12 @@ static void on_root_check_toggled(GtkWidget* toggle_button, GtkWidget* entry)
 			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(toggle_button)));
 }
 
+static void on_sb_check_toggled(GtkWidget* toggle_button, GtkWidget* entry)
+{
+	gtk_widget_set_sensitive(entry, 
+			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(toggle_button)));	
+}
+
 static gchar*
 get_root_install_command(BasicAutotoolsPlugin *bplugin)
 {
@@ -493,6 +507,26 @@ parse_error_line (const gchar * line, gchar ** filename, int *lineno)
 	return FALSE;
 }
 
+static gchar* get_real_directory(BuildContext* context, gchar* dir)
+{
+	AnjutaPreferences* prefs = anjuta_shell_get_preferences (context->plugin->shell, NULL);
+	gchar* real_dir = dir;
+	if (anjuta_preferences_get_int (prefs, PREF_USE_SB))
+	{
+			gchar* username = getenv("USERNAME");
+			if (!username || strlen(username) == 0)
+				username = getenv("USER");
+			if (!username || strlen(username) == 0)
+				return real_dir;
+		
+		const gchar* sb_dir = anjuta_preferences_get(prefs, PREF_SB_PATH);
+		real_dir = g_strdup_printf("%s/users/%s%s", sb_dir, username, dir);
+		g_free(dir);
+		DEBUG_PRINT("sb_dir = %s", real_dir);
+	}
+	return real_dir;
+}
+
 static void
 on_build_mesg_format (IAnjutaMessageView *view, const gchar *one_line,
 					  BuildContext *context)
@@ -501,17 +535,18 @@ on_build_mesg_format (IAnjutaMessageView *view, const gchar *one_line,
 	gint dummy_int;
 	IAnjutaMessageViewType type;
 	GList *node;
-	gchar dir[2048];
+	gchar* dir = g_new0(gchar, 2048);
 	gchar *summary = NULL;
 	gchar *freeptr = NULL;
 	BasicAutotoolsPlugin *p = ANJUTA_PLUGIN_BASIC_AUTOTOOLS (context->plugin);
 	
 	g_return_if_fail (one_line != NULL);
 	
-	/* FIXME: What about translations in the following sscanf strings */
 	/* The translations should match that of 'make' program */
 	if ((sscanf (one_line, _("make[%d]: Entering directory '%s'"), &dummy_int, dir) == 2) ||
-		(sscanf (one_line, _("make: Entering directory '%s'"), dir) == 1))
+		(sscanf (one_line, _("make: Entering directory '%s'"), dir) == 1) ||
+		(sscanf (one_line, _("make[%d]: Entering directory `%s'"), &dummy_int, dir) == 2) ||
+		(sscanf (one_line, _("make: Entering directory `%s'"), dir) == 1))
 	{
 		gchar* summary;
 		/* FIXME: Hack to remove the last ' */
@@ -519,29 +554,35 @@ on_build_mesg_format (IAnjutaMessageView *view, const gchar *one_line,
 		if (idx != NULL)
 		{
 			*idx = '\0';
-		}
+		}		
+		dir = get_real_directory(context, dir);
+		build_context_push_dir (context, "default", dir);
 		summary = g_strdup_printf(_("Entering: %s"), dir);
 		ianjuta_message_view_append (view, IANJUTA_MESSAGE_VIEW_TYPE_INFO, 
 									 summary, one_line, NULL);
 		g_free(summary);
-		build_context_push_dir (context, "default", dir);
+
 		return;
 	}
 	/* Translation for the following should match that of 'make' program */
 	if ((sscanf (one_line, _("make[%d]: Leaving directory '%s'"), &dummy_int, dir) == 2) ||
-		(sscanf (one_line, _("make: Leaving directory '%s'"), dir) == 1))
+		(sscanf (one_line, _("make: Leaving directory '%s'"), dir) == 1) ||
+		(sscanf (one_line, _("make[%d]: Leaving directory `%s'"), &dummy_int, dir) == 2) ||
+		(sscanf (one_line, _("make: Leaving directory `%s'"), dir) == 1))
 	{
 		gchar* summary;
+		gchar* real_dir;
 		/* FIXME: Hack to remove the last ' */
 		gchar *idx = strchr (dir, '\'');
 		if (idx != NULL)
 		{
 			*idx = '\0';
 		}
+		dir = get_real_directory(context, dir);
+		build_context_pop_dir (context, "default", dir);
 		summary = g_strdup_printf(_("Leaving: %s"), dir);
 		ianjuta_message_view_append (view, IANJUTA_MESSAGE_VIEW_TYPE_INFO, 
 									 summary, one_line, NULL);
-		build_context_pop_dir (context, "default", dir);
 		g_free(summary);
 		return;
 	}
@@ -700,13 +741,7 @@ on_build_terminated (AnjutaLauncher *launcher,
 									   _("Completed... successful\n"), NULL);
 		}
 		ianjuta_message_view_buffer_append (context->message_view, buff1, NULL);
-		/*
-		if (anjuta_preferences_get_int (ANJUTA_PREFERENCES (app->preferences),
-										BEEP_ON_BUILD_COMPLETE))
-			gdk_beep ();
-		*/
 		g_free (buff1);
-		/* anjuta_update_app_status (TRUE, NULL); */
 		
 		/* Goto the first error if it exists */
 		/* if (anjuta_preferences_get_int (ANJUTA_PREFERENCES (app->preferences),
@@ -717,6 +752,7 @@ on_build_terminated (AnjutaLauncher *launcher,
 	if (context->launcher)
 		g_object_unref (context->launcher);
 	context->launcher = NULL;
+	update_project_ui (ANJUTA_PLUGIN_BASIC_AUTOTOOLS (context->plugin));
 }
 
 static void
@@ -847,17 +883,34 @@ save_all_files (AnjutaPlugin *plugin)
 }
 
 static void
-build_execute_command (BasicAutotoolsPlugin* plugin, const gchar *dir,
+build_execute_command (BasicAutotoolsPlugin* bplugin, const gchar *dir,
 					   const gchar *command,
 					   gboolean save_file)
 {
+	AnjutaPlugin* plugin = ANJUTA_PLUGIN(bplugin);
+	AnjutaPreferences* prefs = anjuta_shell_get_preferences (plugin->shell, NULL);
 	BuildContext *context;
+	gchar* real_command;
 	
 	g_return_if_fail (command != NULL);
 
-	if (save_file) save_all_files (ANJUTA_PLUGIN (plugin));
+	if (save_file) 
+		save_all_files (ANJUTA_PLUGIN (plugin));
 	
-	context = build_get_context (plugin, dir, command);
+	context = build_get_context (bplugin, dir, command);
+	
+	if (anjuta_preferences_get_int (prefs , PREF_USE_SB))
+	{
+		const gchar* sb_path = anjuta_preferences_get(prefs, PREF_SB_PATH);
+		/* we need to skip the /scratchbox/users part, maybe could be done more clever */
+		const gchar* real_dir = strstr(dir, "/home");
+		real_command = g_strdup_printf("%s/login -d %s \"%s\"", sb_path,
+									  real_dir, command);
+	}
+	else
+	{
+		real_command = g_strdup(command);
+	}
 	
 	ianjuta_message_view_buffer_append (context->message_view,
 										"Building in directory: ", NULL);
@@ -866,8 +919,9 @@ build_execute_command (BasicAutotoolsPlugin* plugin, const gchar *dir,
 	ianjuta_message_view_buffer_append (context->message_view, command, NULL);
 	ianjuta_message_view_buffer_append (context->message_view, "\n", NULL);
 	
-	anjuta_launcher_execute (context->launcher, command,
+	anjuta_launcher_execute (context->launcher, real_command,
 							 on_build_mesg_arrived, context);
+	g_free(real_command);
 }
 
 static gboolean
@@ -1008,16 +1062,24 @@ build_autogen_project (GtkAction *action, BasicAutotoolsPlugin *plugin)
 										 plugin->configure_args, &input);
 	if (response)
 	{
+		gboolean has_autogen = directory_has_file (plugin->project_root_dir,
+												   "autogen.sh");
 		gchar *cmd;
 		if (input)
 		{
-			cmd = g_strconcat ("./autogen.sh ", input, NULL);
+			if (has_autogen)
+				cmd = g_strconcat ("./autogen.sh ", input, NULL);
+			else
+				cmd = g_strconcat ("autoreconf -i --force ", input, NULL);
 			g_free (plugin->configure_args);
 			plugin->configure_args = input;
 		}
 		else
 		{
-			cmd = g_strdup ("./autogen.sh");
+			if (has_autogen)
+				cmd = g_strdup ("./autogen.sh");
+			else
+				cmd = g_strdup ("autoreconf -i --force");
 		}
 		build_execute_command (plugin, plugin->project_root_dir, cmd, TRUE);
 		g_free (cmd);
@@ -1423,12 +1485,9 @@ update_project_ui (BasicAutotoolsPlugin *bb_plugin)
 									   "ActionBuildConfigure");
 		g_object_set (G_OBJECT (action), "sensitive", TRUE, NULL);
 	}
-	if (directory_has_file (bb_plugin->project_root_dir, "autogen.sh"))
-	{
-		action = anjuta_ui_get_action (ui, "ActionGroupBuild",
-									   "ActionBuildAutogen");
-		g_object_set (G_OBJECT (action), "sensitive", TRUE, NULL);
-	}
+	action = anjuta_ui_get_action (ui, "ActionGroupBuild",
+								   "ActionBuildAutogen");
+	g_object_set (G_OBJECT (action), "sensitive", TRUE, NULL);
 }
 
 static gchar*
@@ -2087,7 +2146,15 @@ ibuildable_generate (IAnjutaBuildable *manager, const gchar *directory,
 					 GError **err)
 {
 	BasicAutotoolsPlugin *plugin = ANJUTA_PLUGIN_BASIC_AUTOTOOLS (manager);
-	build_execute_command (plugin, directory, "./autogen.sh", FALSE);
+	if (directory_has_file (plugin->project_root_dir, "autogen.sh"))
+	{
+		build_execute_command (plugin, directory, "./autogen.sh", FALSE);
+	}
+	else
+	{
+		build_execute_command (plugin, directory,
+							   "autoreconf -i --force", FALSE);
+	}
 }
 
 static void
@@ -2140,14 +2207,21 @@ static void
 ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError** e)
 {
 	GtkWidget *root_check;
+	GtkWidget *sb_check;
 	GtkWidget *entry;
+	GtkWidget *sb_entry;
 		
 	/* Create the preferences page */
 	gxml = glade_xml_new (GLADE_FILE, "preferences_dialog_build", NULL);
 	root_check = glade_xml_get_widget(gxml, CHECK_BUTTON);
+	sb_check = glade_xml_get_widget(gxml, SB_CHECK);
 	entry = glade_xml_get_widget(gxml, ENTRY);
+	sb_entry = glade_xml_get_widget(gxml, SB_ENTRY);
+	
 	g_signal_connect(G_OBJECT(root_check), "toggled", G_CALLBACK(on_root_check_toggled), entry);
-		
+	g_signal_connect(G_OBJECT(sb_check), "toggled", G_CALLBACK(on_sb_check_toggled), sb_entry);
+	
+	
 	anjuta_preferences_add_page (prefs, gxml, "Build", _("Build Autotools"),  ICON_FILE);
 }
 
@@ -2155,12 +2229,18 @@ static void
 ipreferences_unmerge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError** e)
 {
 	GtkWidget *root_check;
+	GtkWidget *sb_check;
 	GtkWidget *entry;
-	
+	GtkWidget *sb_entry;
+
 	root_check = glade_xml_get_widget(gxml, CHECK_BUTTON);
+	sb_check = glade_xml_get_widget(gxml, SB_CHECK);
 	entry = glade_xml_get_widget(gxml, ENTRY);
+	sb_entry = glade_xml_get_widget(gxml, SB_ENTRY);
 	g_signal_handlers_disconnect_by_func(G_OBJECT(root_check),
 		G_CALLBACK(on_root_check_toggled), entry);
+	g_signal_handlers_disconnect_by_func(G_OBJECT(root_check),
+		G_CALLBACK(on_sb_check_toggled), sb_entry);
 		
 	anjuta_preferences_dialog_remove_page(ANJUTA_PREFERENCES_DIALOG(prefs),
 		_("Build Autotools"));
