@@ -365,6 +365,7 @@ breakpoint_item_new_from_string (BreakpointsDBase *bd, const gchar* string, cons
 	}
 	
 	bi->uri = g_strdup (uri);
+	bi->bp->enable = IANJUTA_DEBUGGER_YES;
 
 	return bi;
 }
@@ -375,6 +376,12 @@ breakpoint_item_free (BreakpointItem *bi)
 	g_return_if_fail (bi != NULL);
 
 	anjuta_breakpoint_free (bi->bp);
+	
+	if (bi->editor != NULL)
+	{
+		g_object_remove_weak_pointer (G_OBJECT (bi->editor), (gpointer *)&bi->editor);
+	}
+	
 	g_free (bi);
 }
 
@@ -447,13 +454,20 @@ breakpoint_item_update_in_ui (BreakpointItem *bi, const IAnjutaDebuggerBreakpoin
 	
 	/* Update node information */
 	adr = g_strdup_printf ("0x%x", bi->bp->address);
-	filename = strrchr(bi->bp->file, G_DIR_SEPARATOR);
-	filename = filename == NULL ? bi->bp->file : filename + 1; /* display name only */
+	if (bi->bp->file != NULL)
+	{
+		filename = strrchr(bi->bp->file, G_DIR_SEPARATOR);
+		filename = filename == NULL ? bi->bp->file : filename + 1; /* display name only */
+	}
+	else
+	{
+		filename = NULL;
+	}
 	gtk_list_store_set (store, &bi->iter,
 						ENABLED_COLUMN, bi->bp->enable == IANJUTA_DEBUGGER_YES ? TRUE : FALSE,
 						NUMBER_COLUMN, bi->bp->id,
 						DISP_COLUMN, bi->bp->keep == IANJUTA_DEBUGGER_YES ? "keep" : "nokeep",
-						FILENAME_COLUMN, filename,
+						FILENAME_COLUMN, filename == NULL ? "??" : filename,
 						LINENO_COLUMN, bi->bp->line,
 						ADDRESS_COLUMN, adr,
 						TYPE_COLUMN, "breakpoint",
@@ -480,6 +494,7 @@ breakpoint_item_update_in_ui (BreakpointItem *bi, const IAnjutaDebuggerBreakpoin
 			if ((ed != NULL) && (IANJUTA_IS_MARKABLE (ed)))
 			{
 				bi->editor = ed;
+				g_object_add_weak_pointer (G_OBJECT (ed), (gpointer)&bi->editor);
 			}
 		}
 		
@@ -578,7 +593,7 @@ breakpoints_dbase_add_breakpoint (BreakpointsDBase *bd,  BreakpointItem *bi)
 		case IANJUTA_DEBUGGER_BREAK_ON_FUNCTION:
 			ianjuta_debugger_set_breakpoint_at_function (
 					bd->debugger,
-					bi->bp->file,
+					bi->bp->file == NULL ? "" : bi->bp->file,
 					bi->bp->function,
 					(IAnjutaDebuggerCallback)on_breakpoint_item_update_in_ui,
 					bi,
@@ -1075,6 +1090,7 @@ breakpoints_dbase_set_all_in_editor (BreakpointsDBase* bd, IAnjutaEditor* te)
 			if (strcmp (uri, bi->uri) == 0)
 			{
 				bi->editor = te;
+				g_object_add_weak_pointer (G_OBJECT (te), (gpointer)&bi->editor);
 				set_breakpoint_in_editor (bi, bi->bp->enable == IANJUTA_DEBUGGER_YES ? BREAKPOINT_ENABLED : BREAKPOINT_DISABLED, FALSE);
 			}
 		} while (gtk_tree_model_iter_next (model, &iter));
@@ -1102,7 +1118,11 @@ breakpoints_dbase_clear_all_in_editor (BreakpointsDBase* bd, IAnjutaEditor* te)
 		
 			gtk_tree_model_get (model, &iter, DATA_COLUMN, &bi, -1);
 
-			if (bi->editor == te) bi->editor = NULL;
+			if (bi->editor == te)
+			{       
+				bi->editor = NULL;
+				g_object_remove_weak_pointer (G_OBJECT (te), (gpointer *)&bi->editor);
+			}
 		} while (gtk_tree_model_iter_next (model, &iter));
 	}
 }
@@ -1469,7 +1489,7 @@ on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase, AnjutaSession *se
 	if (phase != ANJUTA_SESSION_PHASE_NORMAL)
 		return;
 
-	/* breakpoints_dbase_remove_all (bd); */
+	breakpoints_dbase_remove_all (bd);
 	list = anjuta_session_get_string_list (session, "Debugger", "Breakpoint");
 	if (list != NULL)
 		breakpoints_dbase_add_breakpoint_list (bd, list);
