@@ -1,3 +1,4 @@
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
     disassemble.h
     Copyright (C) 2006 Sebastien Granjoux
@@ -31,6 +32,12 @@ typedef struct _DmaDisassemble DmaDisassemble;
 DmaDisassemble* dma_disassemble_new (AnjutaPlugin *plugin, IAnjutaDebugger *debugger);
 void dma_disassemble_free(DmaDisassemble *self);
 
+void dma_disassemble_mark (DmaDisassemble *self, guint address, gint marker);
+void dma_disassemble_unmark (DmaDisassemble *self, guint address, gint marker);
+void dma_disassemble_goto_address (DmaDisassemble *self, guint address);
+void dma_disassemble_clear_all_mark (DmaDisassemble *self, gint marker);
+
+
 G_END_DECLS
 
 #endif /* _DISASSEMBLE_H */
