@@ -38,7 +38,7 @@
 #include <libanjuta/interfaces/ianjuta-editor-selection.h>
 #include <libanjuta/interfaces/ianjuta-editor-convert.h>
 #include <libanjuta/interfaces/ianjuta-editor-line-mode.h>
-#include <libanjuta/interfaces/ianjuta-editor-assist.h>
+#include <libanjuta/interfaces/ianjuta-editor-autocomplete.h>
 #include <libanjuta/interfaces/ianjuta-editor-view.h>
 #include <libanjuta/interfaces/ianjuta-editor-folds.h>
 #include <libanjuta/interfaces/ianjuta-editor-comment.h>
@@ -1313,9 +1313,9 @@ load_from_file (TextEditor *te, gchar *uri, gchar **err)
 	GnomeVFSResult result;
 	GnomeVFSFileInfo info;
 	GnomeVFSFileSize nchars;
-	gchar *file_content;
-	gchar *buffer;
 	gint dos_filter, editor_mode;
+	gchar *file_content = NULL;
+	gchar *buffer = NULL;
 
 	scintilla_send_message (SCINTILLA (te->scintilla), SCI_CLEARALL,
 							0, 0);
@@ -1326,7 +1326,7 @@ load_from_file (TextEditor *te, gchar *uri, gchar **err)
 		*err = g_strdup (_("Could not get file info"));
 		return FALSE;
 	}
-	buffer = g_malloc (info.size);
+	buffer = g_malloc (info.size + 1);
 	if (buffer == NULL && info.size != 0)
 	{
 		/* DEBUG_PRINT ("This file is too big. Unable to allocate memory."); */
@@ -1349,8 +1349,12 @@ load_from_file (TextEditor *te, gchar *uri, gchar **err)
 		return FALSE;
 	}
 	
-	file_content = g_strdup (buffer);
-
+	if (buffer)
+	{
+		buffer[info.size] = '\0';
+		file_content = g_strdup (buffer);
+	}
+	
 	if (info.size != nchars)
 	{
 		/* DEBUG_PRINT ("File size and loaded size not matching"); */
@@ -2871,18 +2875,75 @@ ilinemode_iface_init (IAnjutaEditorLineModeIface *iface)
 	iface->fix = ilinemode_fix;
 }
 
-/* IAnjutaEditorAssist implementation */
+/* IAnjutaEditorAutocomplete implementation */
 static void 
-iassist_autocomplete(IAnjutaEditorAssist* te, GError** ee)
+iautocomplete_activate (IAnjutaEditorAutocomplete* te, GError** ee)
 {
 	text_editor_command(TEXT_EDITOR(te), ANE_COMPLETEWORD, 0, 0);
 }
 
+static void
+iautocomplete_iface_init(IAnjutaEditorAutocompleteIface* iface)
+{
+	iface->activate = iautocomplete_activate;
+}
+
+/* IAnjutaEditorAssist implementation */
+#if 0
+static void
+iassist_add_trigger (IAnjutaEditorAssist* iassist, const gchar* trigger,
+					 IAnjutaEditorAssistContextParser context_parser, GError **err)
+{
+	/* FIXME: Implement new IAnjutaEditorAssist interface */
+}
+
+static void
+iassist_remove_trigger (IAnjutaEditorAssist* iassist, const gchar* trigger, GError **err)
+{
+	/* FIXME: Implement new IAnjutaEditorAssist interface */
+}
+
+static void
+iassist_suggest (IAnjutaEditorAssist *iassist, GList* choices, int char_alignment, GError **err)
+{
+	/* FIXME: Implement new IAnjutaEditorAssist interface */
+}
+
+static GList*
+iassist_get_suggestions (IAnjutaEditorAssist *iassist, const gchar *context, GError **err)
+{
+	/* FIXME: Implement new IAnjutaEditorAssist interface */
+
+	return NULL;
+}
+
+static void 
+iassist_tip (IAnjutaEditorAssist *iassist, GList* tips,  gint char_alignment, GError **err)
+{
+	/* FIXME: Implement new IAnjutaEditorAssist interface */
+}
+
+static void
+iassist_react (IAnjutaEditorAssist *iassist, gint selection,  
+			   const gchar *completion, GError **err)
+{
+
+	/* FIXME: Implement new IAnjutaEditorAssist interface */
+}
+
 static void
 iassist_iface_init(IAnjutaEditorAssistIface* iface)
 {
 	iface->autocomplete = iassist_autocomplete;
+	iface->add_trigger = iassist_add_trigger;
+	iface->remove_trigger = iassist_remove_trigger;
+	iface->suggest = iassist_suggest;
+	iface->get_suggestions = iassist_get_suggestions;
+	iface->tip = iassist_tip;
+	iface->react = iassist_react;
 }
+#endif
+
 
 /* IAnutaEditorFolds implementation */
 
@@ -3332,7 +3393,7 @@ ANJUTA_TYPE_ADD_INTERFACE(itext_editor, IANJUTA_TYPE_EDITOR);
 ANJUTA_TYPE_ADD_INTERFACE(ilinemode, IANJUTA_TYPE_EDITOR_LINE_MODE);
 ANJUTA_TYPE_ADD_INTERFACE(iselection, IANJUTA_TYPE_EDITOR_SELECTION);
 ANJUTA_TYPE_ADD_INTERFACE(iconvert, IANJUTA_TYPE_EDITOR_CONVERT);
-ANJUTA_TYPE_ADD_INTERFACE(iassist, IANJUTA_TYPE_EDITOR_ASSIST);
+ANJUTA_TYPE_ADD_INTERFACE(iautocomplete, IANJUTA_TYPE_EDITOR_AUTOCOMPLETE);
 ANJUTA_TYPE_ADD_INTERFACE(ilanguage, IANJUTA_TYPE_EDITOR_LANGUAGE);
 ANJUTA_TYPE_ADD_INTERFACE(iview, IANJUTA_TYPE_EDITOR_VIEW);
 ANJUTA_TYPE_ADD_INTERFACE(ifolds, IANJUTA_TYPE_EDITOR_FOLDS);
