@@ -90,9 +90,10 @@ static void on_view_changed(AnjutaMsgman* msgman, MessageViewPlugin* plugin)
 								   "ActionMessageNext");
 	GtkAction* action_prev = anjuta_ui_get_action (ui, "ActionGroupGotoMessages",
 								   "ActionMessagePrev");
-	anjuta_shell_present_widget (ANJUTA_PLUGIN (plugin)->shell,
-								 GTK_WIDGET(msgman), NULL);
 	gboolean sensitive = (anjuta_msgman_get_current_view(msgman) != NULL);
+	if (sensitive)
+		anjuta_shell_present_widget (ANJUTA_PLUGIN (plugin)->shell,
+								 GTK_WIDGET(msgman), NULL);
 	g_object_set (G_OBJECT (action_next), "sensitive", sensitive, NULL);
 	g_object_set (G_OBJECT (action_prev), "sensitive", sensitive, NULL);
 }
@@ -143,6 +144,8 @@ register_stock_icons (AnjutaPlugin *plugin)
 	gtk_icon_source_free (source);
 }
 
+#if 0 /* Disable session saving/loading until a way is found to avoid
+       * number of message panes infinitely growing */
 static void
 on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
 				 AnjutaSession *session, MessageViewPlugin *plugin)
@@ -200,6 +203,7 @@ on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase,
 	g_object_unref (serializer);
 	g_free (messages_file);
 }
+#endif
 
 static gboolean
 activate_plugin (AnjutaPlugin *plugin)
@@ -240,11 +244,13 @@ activate_plugin (AnjutaPlugin *plugin)
 							 "AnjutaMessageView", _("Messages"),
 							 "message-manager-plugin-icon",
 							 ANJUTA_SHELL_PLACEMENT_BOTTOM, NULL);
+#if 0
 	/* Connect to save and load session */
 	g_signal_connect (G_OBJECT (plugin->shell), "save-session",
 					  G_CALLBACK (on_session_save), plugin);
 	g_signal_connect (G_OBJECT (plugin->shell), "load-session",
 					  G_CALLBACK (on_session_load), plugin);
+#endif
 	initialized = TRUE;
 	return TRUE;
 }
@@ -258,7 +264,7 @@ deactivate_plugin (AnjutaPlugin *plugin)
 	DEBUG_PRINT ("MessageViewPlugin: Dectivating message view plugin ...");
 	
 	mplugin = ANJUTA_PLUGIN_MESSAGE_VIEW (plugin);
-	
+#if 0
 	/* Disconnect signals */
 	g_signal_handlers_disconnect_by_func (G_OBJECT (plugin->shell),
 										  G_CALLBACK (on_session_save),
@@ -266,7 +272,7 @@ deactivate_plugin (AnjutaPlugin *plugin)
 	g_signal_handlers_disconnect_by_func (G_OBJECT (plugin->shell),
 										  G_CALLBACK (on_session_load),
 										  plugin);
-	
+#endif
 	/* Widget is destroyed as soon as it is removed */
 	anjuta_shell_remove_widget (plugin->shell, mplugin->msgman, NULL);
 	anjuta_ui_unmerge (ui, mplugin->uiid);
@@ -324,7 +330,9 @@ ianjuta_msgman_add_view (IAnjutaMessageManager *plugin,
 						 GError **e)
 {
 	MessageView* message_view;
+	AnjutaShell* shell = ANJUTA_PLUGIN(plugin)->shell;
 	GtkWidget *msgman = ANJUTA_PLUGIN_MESSAGE_VIEW (plugin)->msgman;
+	anjuta_shell_present_widget(shell, msgman, NULL);
 	message_view = anjuta_msgman_add_view (ANJUTA_MSGMAN (msgman), file, icon);
 	return IANJUTA_MESSAGE_VIEW (message_view);
 }
