@@ -67,42 +67,35 @@ setup_options (Profiler *profiler)
 	options = g_ptr_array_new ();
 	
 	/* First handle the easy ones: -a, -c, and -z */
-	if (anjuta_preferences_get_int (profiler->prefs, 
-									"profiler.no_show_static"))
+	if (gprof_options_get_int (profiler->options, "no_show_static"))
 	{
 		g_ptr_array_add (options, g_strdup ("-a"));
 	}
 	
-	if (anjuta_preferences_get_int (profiler->prefs,
-								    "profiler.show_possible_called"))
+	if (gprof_options_get_int (profiler->options, "show_possible_called"))
 	{
 		g_ptr_array_add (options, g_strdup ("-c"));
 	}
 	
-	if (anjuta_preferences_get_int (profiler->prefs,
-									"profiler.show_uncalled"))
+	if (gprof_options_get_int (profiler->options, "show_uncalled"))
 	{
 		g_ptr_array_add (options, g_strdup ("-z"));
 	}
 	
 	/* If the user wants to modify the call graph, put in -p so we have a flat
 	 * profile. */
-	if (!anjuta_preferences_get_int (profiler->prefs,
-									 "profiler.show_all_symbols"))
+	if (!gprof_options_get_int (profiler->options, "show_all_symbols"))
 	{
 		g_ptr_array_add (options, g_strdup ("-p"));
 		
-		symbols = anjuta_preferences_get (profiler->prefs,
-										  "profiler.symbols");
+		symbols = gprof_options_get_string (profiler->options, "symbols");
 	
-		if (anjuta_preferences_get_int (profiler->prefs,
-										"profiler.include_symbols"))
+		if (gprof_options_get_int (profiler->options, "include_symbols"))
 		{
 			add_options_strings (options, "-q", symbols);
 		}
 		
-		if (anjuta_preferences_get_int (profiler->prefs,
-										"profiler.exclude_symbols"))
+		if (gprof_options_get_int (profiler->options, "exclude_symbols"))
 		{
 			add_options_strings (options, "-Q", symbols);
 		}
@@ -111,21 +104,20 @@ setup_options (Profiler *profiler)
 	}
 	
 	/* Time propagation options */
-	if (!anjuta_preferences_get_int (profiler->prefs,
-									 "profiler_propagate_all_symbols"))
+	if (!gprof_options_get_int (profiler->options, "propagate_all_symbols"))
 	{
 	
-		symbols = anjuta_preferences_get (profiler->prefs,
-										  "profiler.propagation_symbols");
+		symbols = gprof_options_get_string (profiler->options,
+										  	 "propagation_symbols");
 		
-		if (anjuta_preferences_get_int (profiler->prefs,
-										"profiler.propagate_include_symbols"))
+		if (gprof_options_get_int (profiler->options,
+								   "propagate_include_symbols"))
 		{
 			add_options_strings (options, "-n", symbols);
 		}
 		
-		if (anjuta_preferences_get_int (profiler->prefs,
-										"profiler.propagate_exclude_symbols"))
+		if (gprof_options_get_int (profiler->options,
+								   "propagate_exclude_symbols"))
 		{
 			add_options_strings (options, "-N", symbols);
 		}
@@ -144,8 +136,7 @@ setup_options (Profiler *profiler)
 	 
 	 if (profiler->profile_data_monitor)
 	 {
-	 	if (!anjuta_preferences_get_int (profiler->prefs,
-	 									 "profiler.automatic_refresh"))
+	 	if (!gprof_options_get_int (profiler->options, "automatic_refresh"))
 	 	{
 	 		gnome_vfs_monitor_cancel (profiler->profile_data_monitor);
 	 		profiler->profile_data_monitor = NULL;
@@ -160,17 +151,29 @@ profiler_get_data (Profiler *profiler)
 {
 	GPtrArray *options;
 	gchar **option_strings;
+	gchar *profiling_data_path;
+	gchar *profiling_data_path_from_options;
 	gboolean ret = FALSE;
 	
 	if (profiler->profile_target_path)
 	{
 
 		options = setup_options (profiler);
+		
+		profiling_data_path_from_options = gprof_options_get_string (profiler->options,
+																	 "profile_data_file");
+		
+		if (strlen (profiling_data_path_from_options) > 0)
+			profiling_data_path = profiling_data_path_from_options;
+		else
+			profiling_data_path = NULL;
+		
 		if (!gprof_profile_data_init_profile (profiler->profile_data, 
-										 	 profiler->profile_target_path,
-										 	 options))
+										 	  profiler->profile_target_path,
+											  profiling_data_path,
+										 	  options))
 		{
-			anjuta_util_dialog_error (ANJUTA_PLUGIN (profiler)->shell,
+			anjuta_util_dialog_error (GTK_WINDOW (ANJUTA_PLUGIN (profiler)->shell),
 									  _("Could not get profiling data."
 										"\n\n"
 										"Please check the path to "
@@ -178,6 +181,7 @@ profiler_get_data (Profiler *profiler)
 		}
 											 
 		option_strings = (gchar **) g_ptr_array_free (options, FALSE);
+		g_free (profiling_data_path_from_options);
 		g_strfreev (option_strings);
 		
 		ret = TRUE;
@@ -216,8 +220,9 @@ profiler_set_target (Profiler *profiler, const gchar *profile_target_uri)
 {
 	gchar *profile_target_path;
 	gchar *profile_target_dir;
-	gchar *gmon_out_path;
-	gchar *gmon_out_uri;
+	gchar *profile_data_path;
+	gchar *profile_data_path_from_options;
+	gchar *profile_data_uri;
 	
 	if (profiler->profile_target_path)
 	{
@@ -228,26 +233,41 @@ profiler_set_target (Profiler *profiler, const gchar *profile_target_uri)
 	if (profile_target_uri)
 	{
 		profile_target_path = gnome_vfs_get_local_path_from_uri (profile_target_uri);
-		profile_target_dir = g_path_get_dirname (profile_target_path);
-		gmon_out_path = g_build_filename (profile_target_dir, "gmon.out", 
-										  NULL);
-		gmon_out_uri = gnome_vfs_get_uri_from_local_path (gmon_out_path);
 		
-		if (g_file_test (gmon_out_path, G_FILE_TEST_EXISTS))
+		profile_data_path_from_options = gprof_options_get_string (profiler->options,
+																   "profile_data_file");
+		
+		if (strlen (profile_data_path_from_options) > 0)
+		{
+			profile_data_path = g_strdup (profile_data_path_from_options);
+			profile_target_dir = NULL;
+		}
+		else
+		{
+			profile_target_dir = g_path_get_dirname (profile_target_path);
+			profile_data_path = g_build_filename (profile_target_dir, "gmon.out", 
+										  		  NULL);
+		}
+		
+		g_free (profile_data_path_from_options);
+		
+		profile_data_uri = gnome_vfs_get_uri_from_local_path (profile_data_path);
+		
+		if (g_file_test (profile_data_path, G_FILE_TEST_EXISTS))
 		{
 			profiler->profile_target_path = profile_target_path;
 		
 		
 			/* Set up a file change monitor for automatic refresh if enabled */
-			if (anjuta_preferences_get_int (profiler->prefs, 
-											"profiler.automatic_refresh"))
+			if (gprof_options_get_int (profiler->options, 
+									   "automatic_refresh"))
 			{
 				/* Cancel any existing monitor */
 				if (profiler->profile_data_monitor)
 					gnome_vfs_monitor_cancel (profiler->profile_data_monitor);
 				
 				gnome_vfs_monitor_add (&profiler->profile_data_monitor,
-									   gmon_out_uri, GNOME_VFS_MONITOR_FILE,  
+									   profile_data_uri, GNOME_VFS_MONITOR_FILE,  
 									   on_profile_data_changed,
 									   (gpointer) profiler);
 			}
@@ -270,122 +290,189 @@ profiler_set_target (Profiler *profiler, const gchar *profile_target_uri)
 		}
 		
 		g_free (profile_target_dir);
-		g_free (gmon_out_path);
-		g_free (gmon_out_uri);
+		g_free (profile_data_path);
+		g_free (profile_data_uri);
 	}
 }
 
-static AnjutaPreferences *
-register_preferences (GladeXML *gxml)
+static GProfOptions *
+register_options ()
 {
-	AnjutaPreferences *preferences;
-	GtkWidget *prefs_widget;  /* Widget regestered with prefs */
+	GProfOptions *options;
 	
-	preferences = ANJUTA_PREFERENCES (anjuta_preferences_new ());
+	options = gprof_options_new ();
 	
-	prefs_widget = glade_xml_get_widget (gxml, "automatic_refresh_check");
-	anjuta_preferences_register_property_raw (preferences, prefs_widget, 
-											  "profiler.automatic_refresh",
-											  "0", 0, 
-											  ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE,
-											  ANJUTA_PROPERTY_DATA_TYPE_BOOL);
+	gprof_options_register_key (options, "automatic_refresh", "0",
+								"automatic_refresh_check", 
+								OPTION_TYPE_TOGGLE);
 	
-	prefs_widget = glade_xml_get_widget (gxml, "no_show_static_check");
-	anjuta_preferences_register_property_raw (preferences, prefs_widget, 
-											  "profiler.no_show_static",
-											  "0", 0, 
-											  ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE,
-											  ANJUTA_PROPERTY_DATA_TYPE_BOOL);
+	gprof_options_register_key (options, "no_show_static", "0",
+								"no_show_static_check", 
+								OPTION_TYPE_TOGGLE);
 											  
-	prefs_widget = glade_xml_get_widget (gxml, "show_possible_called_check");
-	anjuta_preferences_register_property_raw (preferences, prefs_widget, 
-											  "profiler.show_possible_called",
-											  "0", 0, 
-											  ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE,
-											  ANJUTA_PROPERTY_DATA_TYPE_BOOL);
-											  
-	prefs_widget = glade_xml_get_widget (gxml, "show_uncalled_check");
-	anjuta_preferences_register_property_raw (preferences, prefs_widget, 
-											  "profiler.show_uncalled",
-											  "0", 0, 
-											  ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE,
-											  ANJUTA_PROPERTY_DATA_TYPE_BOOL);
+	gprof_options_register_key (options, "show_possible_called", "0",
+								"show_possible_called_check",
+								OPTION_TYPE_TOGGLE);
+																		  
+	gprof_options_register_key (options, "show_uncalled", "0",
+								"show_uncalled_check", 
+								OPTION_TYPE_TOGGLE);
 	
-	prefs_widget = glade_xml_get_widget (gxml, "show_all_symbols_radio");
-	anjuta_preferences_register_property_raw (preferences, prefs_widget, 
-											  "profiler.show_all_symbols",
-											  "1", 0, 
-											  ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE,
-											  ANJUTA_PROPERTY_DATA_TYPE_BOOL);
+	gprof_options_register_key (options, "show_all_symbols", "1",
+								"show_all_symbols_radio",
+								OPTION_TYPE_TOGGLE);
 	
-	prefs_widget = glade_xml_get_widget (gxml, "include_symbols_radio");
-	anjuta_preferences_register_property_raw (preferences, prefs_widget, 
-											  "profiler.include_symbols",
-											  "0", 0, 
-											  ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE,
-											  ANJUTA_PROPERTY_DATA_TYPE_BOOL);
+	gprof_options_register_key (options, "include_symbols", "0",
+								"include_symbols_radio",
+								OPTION_TYPE_TOGGLE);
 	
-	prefs_widget = glade_xml_get_widget (gxml, "exclude_symbols_radio");
-	anjuta_preferences_register_property_raw (preferences, prefs_widget, 
-											  "profiler.exclude_symbols",
-											  "0", 0, 
-											  ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE,
-											  ANJUTA_PROPERTY_DATA_TYPE_BOOL);
-											  
-	prefs_widget = glade_xml_get_widget (gxml, "symbols_text_view");
-	anjuta_preferences_register_property_raw (preferences, prefs_widget, 
-											  "profiler.symbols",
-											  "", 0, 
-											  ANJUTA_PROPERTY_OBJECT_TYPE_TEXT,
-											  ANJUTA_PROPERTY_DATA_TYPE_TEXT);
-											  
+	gprof_options_register_key (options, "exclude_symbols", "0",
+								"exclude_symbols_radio",
+								OPTION_TYPE_TOGGLE);
 	
-	prefs_widget = glade_xml_get_widget (gxml, "propagate_all_symbols_radio");
-	anjuta_preferences_register_property_raw (preferences, prefs_widget, 
-											  "profiler.propagate_all_symbols",
-											  "0", 0, 
-											  ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE,
-											  ANJUTA_PROPERTY_DATA_TYPE_BOOL);
+	gprof_options_register_key (options, "symbols", "", "symbols_text_view",
+								OPTION_TYPE_TEXT_ENTRY);
 											  
-	prefs_widget = glade_xml_get_widget (gxml, "propagate_include_symbols_radio");
-	anjuta_preferences_register_property_raw (preferences, prefs_widget, 
-											  "profiler.propagate_include_symbols",
-											  "0", 0, 
-											  ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE,
-											  ANJUTA_PROPERTY_DATA_TYPE_BOOL);
-											  
-	prefs_widget = glade_xml_get_widget (gxml, "propagate_exclude_symbols_radio");
-	anjuta_preferences_register_property_raw (preferences, prefs_widget, 
-											  "profiler.propagate_exclude_symbols",
-											  "0", 0, 
-											  ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE,
-											  ANJUTA_PROPERTY_DATA_TYPE_BOOL);
-											  
-	prefs_widget = glade_xml_get_widget (gxml, "propagation_text_view");
-	anjuta_preferences_register_property_raw (preferences, prefs_widget, 
-											  "profiler.propagation_symbols",
-											  "", 0, 
-											  ANJUTA_PROPERTY_OBJECT_TYPE_TEXT,
-											  ANJUTA_PROPERTY_DATA_TYPE_TEXT);										  
+	gprof_options_register_key (options, "propagate_all_symbols", "1",
+								"propagate_all_symbols_radio",
+								OPTION_TYPE_TOGGLE);
 	
-	return preferences;
+	gprof_options_register_key (options, "propagate_include_symbols", "0",
+								"propagate_include_symbols_radio",
+								OPTION_TYPE_TOGGLE);
+											  
+	gprof_options_register_key (options, "propagate_exclude_symbols", "0",
+								"propagate_exclude_symbols_radio", 
+								OPTION_TYPE_TOGGLE);
+											  
+	gprof_options_register_key (options, "propagation_symbols", "",
+								"propagation_text_view",
+								OPTION_TYPE_TEXT_ENTRY);
+	
+	gprof_options_register_key (options, "profile_data_file", "",
+								"profile_data_file_entry",
+								OPTION_TYPE_ENTRY);
+	
+	return options;
+}
+
+static void
+on_profile_data_browse_button_clicked (GtkButton *button, GladeXML *gxml)
+{
+	GtkWidget *select_file_dialog;
+	GtkWidget *profile_data_file_entry;
+	GtkWidget *profiling_options_dialog;
+	gchar *selected_file;
+	
+	profile_data_file_entry = glade_xml_get_widget (gxml, "profile_data_file_entry");
+	profiling_options_dialog = glade_xml_get_widget (gxml,
+													 "profiling_options_dialog");
+	select_file_dialog = gtk_file_chooser_dialog_new ("Select Data File",
+													  GTK_WINDOW (profiling_options_dialog),
+													  GTK_FILE_CHOOSER_ACTION_OPEN,
+													  GTK_STOCK_CANCEL, 
+													  GTK_RESPONSE_CANCEL,
+													  GTK_STOCK_OPEN,
+													  GTK_RESPONSE_ACCEPT,
+													  NULL);
+	
+	if (gtk_dialog_run (GTK_DIALOG (select_file_dialog)) == GTK_RESPONSE_ACCEPT)
+	{
+		selected_file = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (select_file_dialog));
+		gtk_entry_set_text (GTK_ENTRY (profile_data_file_entry), selected_file);
+		g_free (selected_file);
+	}
+	
+	gtk_widget_destroy (select_file_dialog);
 }
 
 static void
 on_profiling_options_button_clicked (GtkButton *button, gpointer *user_data)
 {													 
 	Profiler *profiler;
+	GladeXML *gxml;
 	GtkWidget *profiling_options_dialog;
-	
+	GtkWidget *profile_data_browse_button;
+
 	profiler = PROFILER (user_data);
-	profiling_options_dialog = glade_xml_get_widget (profiler->prefs_gxml,
-													 "profiling_options_dialog");
+	gxml = glade_xml_new (GLADE_FILE, "profiling_options_dialog",
+						  NULL);
+	profiling_options_dialog = glade_xml_get_widget (gxml, "profiling_options_dialog");
+	profile_data_browse_button = glade_xml_get_widget (gxml,
+													   "profile_data_browse_button");
+	
+	g_signal_connect (profile_data_browse_button, "clicked",
+					  G_CALLBACK (on_profile_data_browse_button_clicked),
+					  gxml);
+	
+	g_signal_connect (profiling_options_dialog, "response", G_CALLBACK (gtk_widget_hide),
+					  profiling_options_dialog);
+	
+	gprof_options_create_window (profiler->options, gxml);
+	
+	gtk_window_set_transient_for (GTK_WINDOW (profiling_options_dialog),
+								  GTK_WINDOW (ANJUTA_PLUGIN(profiler)->shell));
 	
-	gtk_widget_show (GTK_WIDGET (profiler->prefs));
-	gtk_widget_hide (GTK_WIDGET (profiler->prefs));
 	gtk_dialog_run (GTK_DIALOG (profiling_options_dialog));
 	
-	gtk_widget_hide (profiling_options_dialog);
+	g_object_unref (gxml);
+}
+
+static void
+on_select_other_target_button_clicked (GtkButton *button, 
+									   GtkTreeView *targets_list_view)
+{
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	gchar *selected_target_path;
+	gchar *selected_target_uri;
+	GtkWidget *target_chooser_dialog;
+	
+	model = gtk_tree_view_get_model (targets_list_view);
+	target_chooser_dialog = gtk_file_chooser_dialog_new ("Select Target",
+														 NULL,
+														 GTK_FILE_CHOOSER_ACTION_OPEN,
+														 GTK_STOCK_CANCEL, 
+														 GTK_RESPONSE_CANCEL,
+														 GTK_STOCK_OPEN,
+														 GTK_RESPONSE_ACCEPT,
+														 NULL);
+	
+	if (gtk_dialog_run (GTK_DIALOG (target_chooser_dialog)) == GTK_RESPONSE_ACCEPT)
+	{
+		selected_target_path = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (target_chooser_dialog));
+		selected_target_uri = gnome_vfs_get_uri_from_local_path (selected_target_path);
+		
+		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, 
+							selected_target_path, 1,
+							selected_target_uri, -1);
+		
+		g_free (selected_target_path);
+		g_free (selected_target_uri);
+	}
+	
+	gtk_widget_destroy (target_chooser_dialog);
+}
+
+static gboolean
+on_target_selected (GtkTreeSelection *selection, GtkTreeModel *model, 
+					GtkTreePath *path, gboolean path_currently_selected,
+					Profiler *profiler)
+{
+	GtkTreeIter list_iter;
+	gchar *target_uri;
+	
+	gtk_tree_model_get_iter (model, &list_iter, path);
+	gtk_tree_model_get (model, &list_iter, 1, &target_uri, -1);
+	
+	if (target_uri)
+	{
+		gprof_options_set_target (profiler->options, target_uri);
+		g_free (target_uri);
+	}
+	
+	return TRUE;
 }
 
 static void
@@ -394,6 +481,7 @@ on_profiler_select_target (GtkAction *action, Profiler *profiler)
 	GladeXML *gxml;
 	GtkWidget *select_target_dialog;
 	GtkWidget *profiling_options_button;
+	GtkWidget *select_other_target_button;
 	GtkWidget *targets_list_view;
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *renderer;
@@ -409,6 +497,45 @@ on_profiler_select_target (GtkAction *action, Profiler *profiler)
 	gchar *relative_path;
 	guint project_root_uri_length;
 	
+	gxml = glade_xml_new (GLADE_FILE, "select_target_dialog", NULL);
+	select_target_dialog = glade_xml_get_widget (gxml, 
+												 "select_target_dialog");
+	targets_list_view = glade_xml_get_widget (gxml, 
+											  "targets_list_view");
+	profiling_options_button = glade_xml_get_widget (gxml,
+													 "profiling_options_button");
+	select_other_target_button = glade_xml_get_widget (gxml,
+													   "select_other_target_button");
+														 
+	g_signal_connect (profiling_options_button, "clicked",
+					  G_CALLBACK (on_profiling_options_button_clicked),
+					  profiler);
+	
+	g_signal_connect (select_other_target_button, "clicked",
+					  G_CALLBACK (on_select_other_target_button_clicked),
+					  targets_list_view);
+		
+	gtk_window_set_transient_for (GTK_WINDOW (select_target_dialog),
+								  GTK_WINDOW (ANJUTA_PLUGIN(profiler)->shell));
+	
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (targets_list_view));
+	gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
+	gtk_tree_selection_set_select_function (selection, 
+											(GtkTreeSelectionFunc) on_target_selected,
+											profiler, NULL);
+	targets_list_store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
+	
+	column = gtk_tree_view_column_new ();
+	gtk_tree_view_column_set_sizing (column,
+									 GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start (column, renderer, FALSE);
+	gtk_tree_view_column_add_attribute (column, renderer, "text",
+												0);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (targets_list_view), column);
+	gtk_tree_view_set_expander_column (GTK_TREE_VIEW (targets_list_view), column);
+	
 	if (profiler->project_root_uri)
 	{
 		project_manager = anjuta_shell_get_interface (ANJUTA_PLUGIN (profiler)->shell,
@@ -419,29 +546,10 @@ on_profiler_select_target (GtkAction *action, Profiler *profiler)
 											 				NULL);
 											 				
 		project_root_uri_length = strlen (profiler->project_root_uri) + 1;
-	
-		gxml = glade_xml_new (GLADE_FILE, "select_target_dialog", NULL);
-		select_target_dialog = glade_xml_get_widget (gxml, 
-													 "select_target_dialog");
-		targets_list_view = glade_xml_get_widget (gxml, 
-												  "targets_list_view");
-		profiling_options_button = glade_xml_get_widget (gxml,
-														 "profiling_options_button");
-														 
-		g_signal_connect (profiling_options_button, "clicked",
-						  G_CALLBACK (on_profiling_options_button_clicked),
-						  profiler);
-		
-		gtk_window_set_transient_for (GTK_WINDOW (select_target_dialog),
-									  GTK_WINDOW (ANJUTA_PLUGIN(profiler)->shell));
-			
+				
 		if (exec_targets)
 		{
 			/* Populate listview */
-			gtk_tree_selection_set_mode (gtk_tree_view_get_selection (GTK_TREE_VIEW
-																	  (targets_list_view)),
-										 							  GTK_SELECTION_BROWSE);
-			targets_list_store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
 			current_target = exec_targets;
 			
 			while (current_target)
@@ -460,41 +568,35 @@ on_profiler_select_target (GtkAction *action, Profiler *profiler)
 			gtk_tree_view_set_model (GTK_TREE_VIEW (targets_list_view),
 									 GTK_TREE_MODEL (targets_list_store));
 			g_object_unref (targets_list_store);
-			
-			column = gtk_tree_view_column_new ();
-			gtk_tree_view_column_set_sizing (column,
-											 GTK_TREE_VIEW_COLUMN_AUTOSIZE);
-
-			renderer = gtk_cell_renderer_text_new ();
-			gtk_tree_view_column_pack_start (column, renderer, FALSE);
-			gtk_tree_view_column_add_attribute (column, renderer, "text",
-												0);
-			gtk_tree_view_append_column (GTK_TREE_VIEW (targets_list_view), column);
-			gtk_tree_view_set_expander_column (GTK_TREE_VIEW (targets_list_view), column);
 		}
-		
-		/* Run dialog */
-		response = gtk_dialog_run (GTK_DIALOG (select_target_dialog));
-		
-		if (response == GTK_RESPONSE_OK)
-		{
-			selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (targets_list_view));
-				
-			if (gtk_tree_selection_get_selected (selection, &model, &iter))
-			{
-				gtk_tree_model_get (model, &iter, 1, &target, -1);
-				profiler_set_target (profiler, target);
-				
-				if (profiler_get_data (profiler))
-					gprof_view_manager_refresh_views (profiler->view_manager);
-			}
-			else
-				profiler_set_target (profiler, NULL);
-		}
-		
-		gtk_widget_destroy (select_target_dialog);
-		g_object_unref (gxml);
 	}
+	else
+	{
+		gtk_tree_view_set_model (GTK_TREE_VIEW (targets_list_view),
+								 GTK_TREE_MODEL (targets_list_store));
+		g_object_unref (targets_list_store);
+	}
+	
+	/* Run dialog */
+	response = gtk_dialog_run (GTK_DIALOG (select_target_dialog));
+		
+	if (response == GTK_RESPONSE_OK)
+	{		
+		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (targets_list_view));
+		if (gtk_tree_selection_get_selected (selection, &model, &iter))
+		{
+			gtk_tree_model_get (model, &iter, 1, &target, -1);
+			profiler_set_target (profiler, target);
+				
+			if (profiler_get_data (profiler))
+				gprof_view_manager_refresh_views (profiler->view_manager);
+		}
+		else
+				profiler_set_target (profiler, NULL);
+	}
+		
+	gtk_widget_hide (select_target_dialog);
+	g_object_unref (gxml);
 }
 
 static void
@@ -508,17 +610,30 @@ static void
 on_profiler_delete_data (GtkAction *action, Profiler *profiler)
 {
 	gchar *profile_target_dir;
-	gchar *gmon_out_path;
+	gchar *profile_data_path_from_options;
+	gchar *profile_data_path;
 	
 	if (profiler->profile_target_path)
 	{
-		profile_target_dir = g_path_get_dirname (profiler->profile_target_path);
-		gmon_out_path = g_build_filename (profile_target_dir, "gmon.out", NULL);
+		profile_data_path_from_options = gprof_options_get_string (profiler->options,
+																   "profile_data_file");
+		/* Delete given path if we have one, or just use the default */
+		if (strlen (profile_data_path_from_options) > 0)
+			g_unlink (profile_data_path_from_options);
+		else
+		{
 		
-		g_unlink (gmon_out_path);
+			profile_target_dir = g_path_get_dirname (profiler->profile_target_path);
+			profile_data_path = g_build_filename (profile_target_dir, 
+											  	  "gmon.out", NULL);
 		
-		g_free (profile_target_dir);
-		g_free (gmon_out_path);
+			g_unlink (profile_data_path);
+			
+			g_free (profile_target_dir);
+			g_free (profile_data_path);
+		}
+		
+		g_free (profile_data_path_from_options);
 	}
 }
 
@@ -527,9 +642,7 @@ project_root_added (AnjutaPlugin *plugin, const gchar *name,
 					const GValue *value, gpointer user_data)
 {
 	Profiler *profiler;
-	AnjutaUI *ui;
 	const gchar *root_uri;
-	GtkAction *action;
 	
 	profiler = PROFILER (plugin);
 	root_uri = g_value_get_string (value);
@@ -538,10 +651,6 @@ project_root_added (AnjutaPlugin *plugin, const gchar *name,
 	{
 		g_free (profiler->project_root_uri);
 		profiler->project_root_uri = g_strdup (root_uri);
-		
-		ui = anjuta_shell_get_ui (plugin->shell, NULL);
-		action = anjuta_ui_get_action (ui, "ActionGroupProfiler", "ActionMenuProfiler");
-		g_object_set (G_OBJECT (action), "sensitive", TRUE, NULL);
 	}
 	
 	
@@ -552,19 +661,54 @@ project_root_removed (AnjutaPlugin *plugin, const gchar *name,
 					  gpointer user_data)
 {
 	Profiler *profiler;
-	AnjutaUI *ui;
-	GtkAction *action;
 	
 	profiler = PROFILER (plugin);
 	
 	g_free (profiler->project_root_uri);
 	profiler->project_root_uri = NULL;
-	
-	ui = anjuta_shell_get_ui (plugin->shell, NULL);
-	action = anjuta_ui_get_action (ui, "ActionGroupProfiler", "ActionMenuProfiler");
-	g_object_set (G_OBJECT (action), "sensitive", FALSE, NULL);
 }
 
+static void
+on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase,
+				 AnjutaSession *session,
+				 Profiler *plugin)
+{
+	const gchar *session_dir;
+	gchar *settings_file_path;
+	
+	if (phase == ANJUTA_SESSION_PHASE_NORMAL)
+	{
+		session_dir = anjuta_session_get_session_directory (session);
+		settings_file_path = g_build_filename (session_dir, 
+											   "profiler-settings.xml", 
+											   NULL);
+	
+		gprof_options_load (plugin->options, settings_file_path);
+	
+		g_free (settings_file_path);
+	}
+}
+
+static void
+on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
+				 AnjutaSession *session,
+				 Profiler *plugin)
+{
+	const gchar *session_dir;
+	gchar *settings_file_path;
+	
+	if (phase == ANJUTA_SESSION_PHASE_NORMAL)
+	{
+		session_dir = anjuta_session_get_session_directory (session);
+		settings_file_path = g_build_filename (session_dir, 
+											   "profiler-settings.xml", 
+											   NULL);
+	
+		gprof_options_save (plugin->options, settings_file_path);
+	
+		g_free (settings_file_path);
+	}
+}
 
 
 static GtkActionEntry actions_file[] = {
@@ -642,6 +786,8 @@ profiler_activate (AnjutaPlugin *plugin)
 
 	AnjutaUI *ui;
 	Profiler *profiler;
+	IAnjutaSymbolManager *symbol_manager;
+	IAnjutaDocumentManager *document_manager;
 	
 	DEBUG_PRINT ("Profiler: Activating Profiler plugin ...");
 	profiler = PROFILER (plugin);
@@ -662,19 +808,35 @@ profiler_activate (AnjutaPlugin *plugin)
 	profiler->view_manager = gprof_view_manager_new ();
 	profiler->profile_data = gprof_profile_data_new ();
 	
+	symbol_manager = anjuta_shell_get_interface (plugin->shell, 
+												 IAnjutaSymbolManager,
+												 NULL);
+	
+	document_manager = anjuta_shell_get_interface (plugin->shell, 
+												   IAnjutaDocumentManager,
+												   NULL);
+	
 	gprof_view_manager_add_view (profiler->view_manager,
-								 GPROF_VIEW (gprof_flat_profile_view_new (profiler->profile_data)),
+								 GPROF_VIEW (gprof_flat_profile_view_new (profiler->profile_data,
+																		  symbol_manager,
+																		  document_manager)),
 								 _("Flat Profile"));
 	gprof_view_manager_add_view (profiler->view_manager,
-								 GPROF_VIEW (gprof_call_graph_view_new (profiler->profile_data)),
+								 GPROF_VIEW (gprof_call_graph_view_new (profiler->profile_data,
+																		symbol_manager,
+																		document_manager)),
 								 _("Call Graph"));
 	gprof_view_manager_add_view (profiler->view_manager,
-								 GPROF_VIEW (gprof_function_call_tree_view_new (profiler->profile_data)),
+								 GPROF_VIEW (gprof_function_call_tree_view_new (profiler->profile_data,
+																				symbol_manager,
+																				document_manager)),
 								 _("Function Call Tree"));
 	
 #ifdef HAVE_GRAPHVIZ
 	gprof_view_manager_add_view (profiler->view_manager,
-								 GPROF_VIEW (gprof_function_call_chart_view_new (profiler->profile_data)),
+								 GPROF_VIEW (gprof_function_call_chart_view_new (profiler->profile_data,
+																				 symbol_manager,
+																				 document_manager)),
 								 _("Function Call Chart"));
 #endif
 								 
@@ -690,9 +852,14 @@ profiler_activate (AnjutaPlugin *plugin)
 										 				  project_root_added, 
 										 				  project_root_removed, NULL);
 										 				  
-	profiler->prefs_gxml = glade_xml_new (GLADE_FILE, "profiling_options_dialog",
-										  NULL);
-	profiler->prefs = register_preferences (profiler->prefs_gxml);
+	profiler->options = register_options ();
+	
+	/* Set up session save/load */
+	g_signal_connect (G_OBJECT (plugin->shell), "save_session", 
+					  G_CALLBACK (on_session_save), plugin);
+	
+	g_signal_connect (G_OBJECT (plugin->shell), "load_session", 
+					  G_CALLBACK (on_session_load), plugin);
 
 	return TRUE;
 }
@@ -706,6 +873,13 @@ profiler_deactivate (AnjutaPlugin *plugin)
 	
 	DEBUG_PRINT ("Profiler: Dectivating Profiler plugin ...");
 
+	/* Disconnect session save/load */
+	g_signal_handlers_disconnect_by_func (G_OBJECT (plugin->shell), 
+										  G_CALLBACK (on_session_save), plugin);
+	
+	g_signal_handlers_disconnect_by_func (G_OBJECT (plugin->shell),
+										  G_CALLBACK (on_session_load), plugin);
+
 	ui = anjuta_shell_get_ui (plugin->shell, NULL);
 	profiler = PROFILER (plugin);
 	
@@ -722,7 +896,7 @@ profiler_deactivate (AnjutaPlugin *plugin)
 	gprof_view_manager_free (profiler->view_manager);
 	gprof_profile_data_free (profiler->profile_data);
 	
-	g_object_unref (profiler->prefs_gxml);
+	gprof_options_destroy (profiler->options);
 	
 	g_free (profiler->project_root_uri);
 	
