@@ -20,7 +20,10 @@
 #include "anjuta-view.h"
 #include "anjuta-document.h"
 
+#include "assist-window.h"
+
 #include <libanjuta/anjuta-plugin.h>
+#include <glib.h>
 
 struct SourceviewPrivate {
 	/* GtkSouceView */
@@ -58,6 +61,10 @@ struct SourceviewPrivate {
 	gboolean saving;
 	gint goto_line;
 	
+	/* Assist */
+	GHashTable* triggers;
+	AssistWindow* assist_win;
+	
 	/* Plugin */
 	AnjutaPlugin* plugin;
 };
