@@ -375,10 +375,6 @@ on_create_tags_clicked (GtkButton *widget, SymbolBrowserPlugin *plugin)
 	AnjutaPreferences *pref;
 	GladeXML *gxml;
 	
-	/* Make sure program anjuta-tags can be found */
-	if (!anjuta_util_prog_is_installed ("anjuta-tags", TRUE))
-		return;
-	
 	pref = plugin->prefs;
 	gxml = glade_xml_new (GLADE_FILE, "create.symbol.tags.dialog", NULL);
 	
@@ -489,7 +485,8 @@ on_create_tags_clicked (GtkButton *widget, SymbolBrowserPlugin *plugin)
 		/* Execute anjuta-tags to create tags for the given files */
 		if ((pid = fork()) == 0)
 		{
-			execvp ("anjuta-tags", argv);
+			execvp (g_build_filename (PACKAGE_DATA_DIR, "scripts",
+									  "anjuta-tags"), argv);
 			perror ("Could not execute anjuta-tags");
 		}
 		waitpid (pid, NULL, 0);
@@ -640,33 +637,59 @@ on_remove_tags_clicked (GtkWidget *button, SymbolBrowserPlugin *plugin)
 	}
 }
 
-static void
-on_message_buffer_flush (IAnjutaMessageView *mesg_view,
-						 const gchar * mesg_line,
-						 gpointer user_data)
-{
-	SymbolBrowserPlugin* plugin = ANJUTA_PLUGIN_SYMBOL_BROWSER (user_data);
-	if (plugin->mesg_view)
-		ianjuta_message_view_append (plugin->mesg_view,
-									 IANJUTA_MESSAGE_VIEW_TYPE_INFO,
-									 mesg_line, "", NULL);
-}
-
 static void
 on_message (AnjutaLauncher *launcher,
 			AnjutaLauncherOutputType output_type,
 			const gchar * mesg, gpointer user_data)
 {
+	AnjutaStatus *status;
+	gchar **lines, **line;
 	SymbolBrowserPlugin* plugin = ANJUTA_PLUGIN_SYMBOL_BROWSER (user_data);
-	if (plugin->mesg_view)
-		ianjuta_message_view_buffer_append (plugin->mesg_view,
-											mesg, NULL);
+	
+	lines = g_strsplit (mesg, "\n", -1);
+	if (!lines)
+		return;
+	
+	status = anjuta_shell_get_status (ANJUTA_PLUGIN (plugin)->shell, NULL);
+	
+	line = lines;
+	while (*line)
+	{
+		gint packages_count;
+		gchar *pos;
+		
+		if (sscanf (*line, "Scanning %d packages", &packages_count) == 1)
+			anjuta_status_progress_add_ticks (status, packages_count + 1);
+		else if ((pos = strstr (*line, ".anjutatags.gz")))
+		{
+			const gchar *package_name;
+		
+			/* Get the name of the package */
+			*pos = '\0';
+			package_name = g_strrstr (*line, "/");
+			if (package_name)
+			{
+				gchar *status_mesg;
+				package_name++;
+				status_mesg = g_strdup_printf (_("Scanning package: %s"),
+											   package_name);
+				anjuta_status_progress_tick (status, NULL, status_mesg);
+				g_free (status_mesg);
+			}
+			else
+				anjuta_status_progress_tick (status, NULL, *line);
+		}
+		line++;
+	}
+	g_strfreev (lines);
 }
 
 static void
-refresh_list (AnjutaLauncher *launcher, gint child_pid, gint status,
-			  gulong time_taken, SymbolBrowserPlugin *plugin)
+on_system_tags_update_finished (AnjutaLauncher *launcher, gint child_pid,
+								gint status, gulong time_taken,
+								SymbolBrowserPlugin *plugin)
 {
+	AnjutaStatus *statusbar;
 	GList *enabled_paths = NULL;
 	GtkTreeIter iter;
 	gchar *tag_path;
@@ -698,12 +721,12 @@ refresh_list (AnjutaLauncher *launcher, gint child_pid, gint status,
 	}
 	g_list_foreach (enabled_paths, (GFunc)g_free, NULL);
 	g_list_free (enabled_paths);
-}
-
-static void
-on_mesg_view_destroy(SymbolBrowserPlugin* plugin, gpointer destroyed_view)
-{
-	plugin->mesg_view = NULL;
+	
+	g_object_unref (plugin->launcher);
+	plugin->launcher = NULL;
+	statusbar = anjuta_shell_get_status (ANJUTA_PLUGIN (plugin)->shell, NULL);
+	anjuta_status_progress_tick (statusbar, NULL,
+								 _("Completed system tags generation"));
 }
 
 static void 
@@ -711,9 +734,11 @@ on_update_global_clicked (GtkWidget *button, SymbolBrowserPlugin *plugin)
 {
 	gchar* tmp;
 	gint pid;
-	AnjutaLauncher* launcher;
 	IAnjutaMessageManager* mesg_manager;
 
+	if (plugin->launcher)
+		return; /* Already running */
+	
 	/* Create local tags directory */	
 	tmp = g_build_filename (g_get_home_dir (), LOCAL_TAGS_DIR, NULL);
 	if ((pid = fork()) == 0)
@@ -723,38 +748,13 @@ on_update_global_clicked (GtkWidget *button, SymbolBrowserPlugin *plugin)
 	}
 	waitpid (pid, NULL, 0);
 	g_free (tmp);
-
-	mesg_manager = anjuta_shell_get_interface 
-		(ANJUTA_PLUGIN (plugin)->shell,	IAnjutaMessageManager, NULL);
 	
-	if (!plugin->mesg_view)
-	{
-		plugin->mesg_view = 
-			ianjuta_message_manager_get_view_by_name(mesg_manager,
-													 _("Create global tags"),
-													 NULL);
-		if (!plugin->mesg_view)
-		{
-			plugin->mesg_view =
-				 ianjuta_message_manager_add_view (mesg_manager,
-												   _("Create global tags"), 
-												  "anjuta-symbol-browser-plugin.png",
-												   NULL);
-		}
-		g_signal_connect (plugin->mesg_view, "buffer-flushed",
-						  G_CALLBACK (on_message_buffer_flush),
-						  plugin);
-		g_object_weak_ref (G_OBJECT (plugin->mesg_view), 
-						  (GWeakNotify)on_mesg_view_destroy, plugin);
-	}
-	ianjuta_message_view_clear(plugin->mesg_view, NULL);
-	ianjuta_message_manager_set_current_view (mesg_manager,
-											  plugin->mesg_view, NULL);
-	
-	launcher = anjuta_launcher_new ();
-	g_signal_connect (G_OBJECT (launcher), "child-exited",
-					  G_CALLBACK (refresh_list), plugin);
-	anjuta_launcher_execute (launcher, CREATE_GLOBAL_TAGS, on_message, plugin);
+	plugin->launcher = anjuta_launcher_new ();
+	g_signal_connect (G_OBJECT (plugin->launcher), "child-exited",
+					  G_CALLBACK (on_system_tags_update_finished), plugin);
+	anjuta_launcher_set_buffered_output (plugin->launcher, TRUE);
+	anjuta_launcher_execute (plugin->launcher, CREATE_GLOBAL_TAGS,
+							 on_message, plugin);
 }
 
 static GtkWidget *
