@@ -24,7 +24,6 @@
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-help.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
-#include <libanjuta/interfaces/ianjuta-message-manager.h>
 #include <libanjuta/interfaces/ianjuta-project-manager.h>
 #include <libanjuta/interfaces/ianjuta-file-manager.h>
 #include <libanjuta/interfaces/ianjuta-file.h>
@@ -1156,7 +1155,6 @@ deactivate_plugin (AnjutaPlugin *plugin)
 	sv_plugin->sv = NULL;
 	sv_plugin->sv_tree = NULL;
 	sv_plugin->ss = NULL;
-	
 	return TRUE;
 }
 
@@ -1205,6 +1203,7 @@ symbol_browser_plugin_instance_init (GObject *obj)
 	plugin->sv = NULL;
 	plugin->gconf_notify_ids = NULL;
 	plugin->locals_line_number = 0;
+	plugin->launcher = NULL;
 }
 
 static void
@@ -1261,7 +1260,7 @@ isymbol_manager_get_members (IAnjutaSymbolManager *sm,
 	AnjutaSymbolIter *iter = NULL;
 	
 	tags_array = tm_workspace_find_scope_members (NULL, symbol_name,
-												  global_search);
+												  global_search, TRUE);
 												  
 	
 	if (tags_array)
