@@ -66,7 +66,7 @@
 
 extern char **environ;
 
-extern GType terminal_plugin_get_type (GluePlugin *plugin);
+extern GType terminal_plugin_get_type (AnjutaGluePlugin *plugin);
 #define ANJUTA_PLUGIN_TERMINAL_TYPE         (terminal_plugin_get_type (NULL))
 #define ANJUTA_PLUGIN_TERMINAL(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), ANJUTA_PLUGIN_TERMINAL_TYPE, TerminalPlugin))
 #define ANJUTA_PLUGIN_TERMINAL_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k), ANJUTA_PLUGIN_TERMINAL_CLASS, TerminalPluginClass))
@@ -275,7 +275,7 @@ on_gconf_notify_prefs (GConfClient *gclient, guint cnxn_id,
 	notify_id = anjuta_preferences_notify_add (tp->prefs, \
 											   key, func, tp, NULL); \
 	tp->gconf_notify_ids = g_list_prepend (tp->gconf_notify_ids, \
-										   (gpointer)(notify_id));
+										   GUINT_TO_POINTER (notify_id));
 static void
 prefs_init (TerminalPlugin *tp)
 {
@@ -291,7 +291,8 @@ prefs_finalize (TerminalPlugin *tp)
 	node = tp->gconf_notify_ids;
 	while (node)
 	{
-		anjuta_preferences_notify_remove (tp->prefs, (guint)node->data);
+		anjuta_preferences_notify_remove (tp->prefs,
+										  GPOINTER_TO_UINT (node->data));
 		node = g_list_next (node);
 	}
 	g_list_free (tp->gconf_notify_ids);
