@@ -34,6 +34,8 @@
 #include <gdl/gdl-dock.h>
 #include <gdl/gdl-dock-bar.h>
 
+#include <bonobo/bonobo-dock-item.h>
+
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-utils.h>
 #include <libanjuta/resources.h>
@@ -138,11 +140,17 @@ on_toolbar_view_toggled (GtkCheckMenuItem *menuitem, GtkWidget *widget)
 	BonoboDockItem *dock_item;
 	const gchar *name;
 	gint band;
+	gint position;
+	gint offset;
+
 	
 	name = gtk_widget_get_name (widget);
 	app = g_object_get_data (G_OBJECT(widget), "app");
 	dock_item = g_object_get_data (G_OBJECT(widget), "dock_item");
 	band = GPOINTER_TO_INT (g_object_get_data (G_OBJECT(widget), "band"));
+	position = GPOINTER_TO_INT (g_object_get_data (G_OBJECT(widget), "position"));
+	offset = GPOINTER_TO_INT (g_object_get_data (G_OBJECT(widget), "offset"));
+
 	
 	if (gtk_check_menu_item_get_active (menuitem))
 	{
@@ -155,19 +163,20 @@ on_toolbar_view_toggled (GtkCheckMenuItem *menuitem, GtkWidget *widget)
 			 * a previously used name (even if the previous widget has
 			 * has be destroyed. Hence a unique_name is used by using a 
 			 * static counter */
-			DEBUG_PRINT ("Adding dock item %s", unique_name);
+			DEBUG_PRINT ("Adding dock item %s band %d, offset %d, position %d", unique_name,
+						 band, offset, position);
 			
 			/* Widget not yet added to the dock. Add it */
 			gnome_app_add_docked (GNOME_APP (app), widget,
 								  unique_name,
 								  BONOBO_DOCK_ITEM_BEH_NEVER_VERTICAL |
 								  BONOBO_DOCK_ITEM_BEH_NEVER_FLOATING,
-								  BONOBO_DOCK_TOP, band, 0, 0);
-		
+								  BONOBO_DOCK_TOP, band, position, offset);
+									   									   
 			dock_item = gnome_app_get_dock_item_by_name (GNOME_APP (app),
 														 unique_name);
+			g_object_set_data (G_OBJECT(dock_item), "unique_name", unique_name);
 			g_object_set_data (G_OBJECT(widget), "dock_item", dock_item);
-			g_free (unique_name);
 			count++;
 		}
 		gtk_widget_show (GTK_WIDGET (dock_item));
@@ -184,6 +193,7 @@ static void
 on_merge_widget_destroy (GtkWidget *merge_widget, GtkWidget *menuitem)
 {
 	toolbars = g_list_remove (toolbars, merge_widget);
+	DEBUG_PRINT ("Destroying menuitem for toolbar widget");
 	gtk_widget_destroy (menuitem);
 }
 
@@ -202,29 +212,42 @@ on_add_merge_widget (GtkUIManager *merge, GtkWidget *widget,
 	{
 		static gint count = 0;
 		const gchar *toolbarname;
-		gchar* key;
+		gchar* visible_key;
+		gchar* band_key;
+		gchar* position_key;
+		gchar* offset_key;		
 		AnjutaPreferences *pr;
 		GtkWidget *menuitem;
+		gint band;
+		gint position;
+		gint offset;
+		pr = ANJUTA_PREFERENCES (ANJUTA_APP(ui_container)->preferences);
 		
-		/*
-		gtk_toolbar_set_icon_size (GTK_TOOLBAR (widget),
-								   GTK_ICON_SIZE_SMALL_TOOLBAR);
-		*/
+		/* Showing the arrows seem to break anything completly! */
 		gtk_toolbar_set_show_arrow (GTK_TOOLBAR (widget), FALSE);
 		
-		/* FIXME: This is probably not HIG-friendly. But the text/both
-		 * toolbar styles in anjuta is horible. We need to fix that first.
-		 */
-		gtk_toolbar_set_style (GTK_TOOLBAR (widget), GTK_TOOLBAR_BOTH_HORIZ);
-		
-		toolbarname = gtk_widget_get_name (widget);
-		
-		DEBUG_PRINT ("Adding toolbar: %s", toolbarname);
-		
 		gtk_widget_show (widget);
 		g_object_set_data (G_OBJECT (widget), "app", ui_container);
+		
+		/* Load toolbar position */
+		toolbarname = gtk_widget_get_name (widget);
+		band_key = g_strconcat (toolbarname, ".band", NULL);
+		position_key = g_strconcat (toolbarname, ".position", NULL);
+		offset_key = g_strconcat (toolbarname, ".offset", NULL);		
+		band = anjuta_preferences_get_int_with_default(pr, band_key, -1);
+		position = anjuta_preferences_get_int_with_default(pr, position_key, 0);
+		offset = anjuta_preferences_get_int_with_default(pr, offset_key, 0);		
+		/* Without these check you might see odd results */
+		if (band < 1)
+			band = count + 1;
+		g_object_set_data(G_OBJECT(widget), "position", GINT_TO_POINTER(position));
+		g_object_set_data(G_OBJECT(widget), "offset", GINT_TO_POINTER(offset));
 		g_object_set_data (G_OBJECT (widget), "band",
-						   GINT_TO_POINTER(count+1));
+						   GINT_TO_POINTER(band));
+		g_free(offset_key);
+		g_free(position_key);
+		g_free(band_key);
+		DEBUG_PRINT ("Adding toolbar: %s", toolbarname);
 		
 		if (!ANJUTA_APP (ui_container)->toolbars_menu)
 		{
@@ -249,15 +272,14 @@ on_add_merge_widget (GtkUIManager *merge, GtkWidget *widget,
 		toolbars = g_list_append(toolbars, widget);
 
 		/* Show/hide toolbar */
-		pr = ANJUTA_PREFERENCES (ANJUTA_APP(ui_container)->preferences);
-		key = g_strconcat (toolbarname, ".visible", NULL);
-		if (anjuta_preferences_get_int_with_default (pr, key,
+		visible_key = g_strconcat (toolbarname, ".visible", NULL);
+		if (anjuta_preferences_get_int_with_default (pr, visible_key,
 													 (count == 0)? 1:0))
 		{
 			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menuitem),
 											TRUE);
 		}
-		g_free (key);
+		g_free (visible_key);
 		count ++;
 	}
 }
@@ -281,13 +303,39 @@ on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
 		GtkWidget* dock_item = g_object_get_data (G_OBJECT(widget), "dock_item");;
 		const gchar* toolbarname = gtk_widget_get_name(widget);
 		AnjutaPreferences* pr = ANJUTA_PREFERENCES (app->preferences);
-		gboolean visible;
+				
 		if (dock_item)
 		{
+			gboolean visible;
 			gchar* key = g_strconcat (toolbarname, ".visible", NULL);
+			gchar* band_key = g_strconcat (toolbarname, ".band", NULL);
+			gchar* position_key = g_strconcat (toolbarname, ".position", NULL);
+			gchar* offset_key = g_strconcat (toolbarname, ".offset", NULL);
+			GnomeApp* gnome_app = GNOME_APP(app);
+			
+			/* Save visibility */
 			g_object_get(G_OBJECT(dock_item), "visible", &visible, NULL);
 			anjuta_preferences_set_int(pr, key, visible);
 			g_free(key);
+			
+			/* Save toolbar position */
+			if (gnome_app->dock != NULL)
+			{
+				guint band;
+				guint position;
+				guint offset;
+				BonoboDockPlacement placement;
+				gchar* unique_name = g_object_get_data(G_OBJECT(dock_item), "unique_name");
+				
+				BonoboDockItem* item = bonobo_dock_get_item_by_name(BONOBO_DOCK(gnome_app->dock), 
+																  unique_name, &placement, 
+																   &band, &position, &offset);
+				g_return_if_fail(item != NULL);
+			
+				anjuta_preferences_set_int(pr, band_key, band);
+				anjuta_preferences_set_int(pr, position_key, position);
+				anjuta_preferences_set_int(pr, offset_key, offset);
+			}
 		}
 		node = g_list_next(node);
 	}
@@ -370,7 +418,8 @@ static void
 anjuta_app_dispose (GObject *widget)
 {
 	AnjutaApp *app;
-
+	GList *tmp_list;
+	
 	g_return_if_fail (ANJUTA_IS_APP (widget));
 	
 	app = ANJUTA_APP (widget);
@@ -403,10 +452,26 @@ anjuta_app_dispose (GObject *widget)
 		app->values = NULL;
 	}
 	
+	/* We need to destroy to the toolbars now so that the
+	 * on_merge_widget_destroy() does not produce a error trying to destory
+	 * already destroyed menuitems which happen when the window is being
+	 * destroyed
+	 *
+	 * Make a tmp list because the handler removes items from 'toolbars' list.
+	 * FIXME: Why is 'toolbars' a global static variable?
+	 */
+	tmp_list = g_list_copy (toolbars);
+	g_list_foreach (tmp_list, (GFunc)gtk_widget_destroy, NULL);
+	g_list_free (tmp_list);
+	
 	if (app->layout_manager) {
 		g_object_unref (app->layout_manager);
 		app->layout_manager = NULL;
 	}
+	if (app->profile_manager) {
+		g_object_unref (G_OBJECT (app->profile_manager));
+		app->profile_manager = NULL;
+	}
 	if (app->plugin_manager) {
 		g_object_unref (G_OBJECT (app->plugin_manager));
 		app->plugin_manager = NULL;
@@ -478,31 +543,18 @@ anjuta_app_instance_init (AnjutaApp *app)
 					  G_CALLBACK (on_layout_dirty_notify), app);
 	g_signal_connect (app->layout_manager->master, "notify::locked",
 					  G_CALLBACK (on_layout_locked_notify), app);
-	
-	/* Create placeholders for default widget positions */
-	gdl_dock_placeholder_new (DOCK_PH_TOP, GDL_DOCK_OBJECT (app->dock),
-							  GDL_DOCK_TOP, FALSE);
-	gdl_dock_placeholder_new (DOCK_PH_BOTTOM, GDL_DOCK_OBJECT (app->dock),
-							  GDL_DOCK_BOTTOM, FALSE);
-	gdl_dock_placeholder_new (DOCK_PH_LEFT, GDL_DOCK_OBJECT (app->dock),
-							  GDL_DOCK_LEFT, FALSE);
-	gdl_dock_placeholder_new (DOCK_PH_RIGHT, GDL_DOCK_OBJECT (app->dock),
-							  GDL_DOCK_RIGHT, FALSE);
-	gdl_dock_placeholder_new ("ph_center", GDL_DOCK_OBJECT (app->dock),
-							  GDL_DOCK_CENTER, FALSE);
-							  
 	/* Status bar */
 	app->status = ANJUTA_STATUS (anjuta_status_new ());
 	anjuta_status_set_title_window (app->status, GTK_WIDGET (app));
 	gtk_widget_show (GTK_WIDGET (app->status));
 	gnome_app_set_statusbar (GNOME_APP (app), GTK_WIDGET (app->status));
 	g_object_ref (G_OBJECT (app->status));
-	g_object_add_weak_pointer (G_OBJECT (app->status), (gpointer*)&app->status);
+	g_object_add_weak_pointer (G_OBJECT (app->status), (gpointer)&app->status);
 	
 	/* Preferences */
 	app->preferences = ANJUTA_PREFERENCES (anjuta_preferences_new ());
 	g_object_add_weak_pointer (G_OBJECT (app->preferences),
-							   (gpointer*)&app->preferences);
+							   (gpointer)&app->preferences);
 	anjuta_status_add_widget (ANJUTA_STATUS (app->status),
 							  GTK_WIDGET (app->preferences));
 	/* UI engine */
@@ -516,13 +568,14 @@ anjuta_app_instance_init (AnjutaApp *app)
 	g_signal_connect (G_OBJECT (app->ui),
 					  "add_widget", G_CALLBACK (on_add_merge_widget),
 					  app);
-	g_object_add_weak_pointer (G_OBJECT (app->ui), (gpointer*)&app->ui);
+	g_object_add_weak_pointer (G_OBJECT (app->ui), (gpointer)&app->ui);
 	
 	/* Plugin Manager */
 	plugins_dirs = g_list_prepend (plugins_dirs, PACKAGE_PLUGIN_DIR);
 	app->plugin_manager = anjuta_plugin_manager_new (G_OBJECT (app),
 													 app->status,
 													 plugins_dirs);
+	app->profile_manager = anjuta_profile_manager_new (app->plugin_manager);
 	g_list_free (plugins_dirs);
 	
 	/* Register actions */
@@ -650,7 +703,6 @@ anjuta_app_set_geometry (AnjutaApp *app, const gchar *geometry)
 {
 	gint width, height, posx, posy;
 	gboolean geometry_set = FALSE;
-	GdlDockPlaceholder *placeholder;
 	
 	if (geometry && strlen (geometry) > 0)
 	{
@@ -689,23 +741,6 @@ anjuta_app_set_geometry (AnjutaApp *app, const gchar *geometry)
 			gtk_window_move (GTK_WINDOW (app), posx, posy);
 		}
 	}
-	/* Set default placeholders geometry */
-	placeholder = gdl_dock_get_placeholder_by_name (GDL_DOCK (app->dock),
-													DOCK_PH_TOP);
-	g_object_set (placeholder, "height", GINT_TO_POINTER((gint)(0.25 * height)),
-				  NULL);
-	placeholder = gdl_dock_get_placeholder_by_name (GDL_DOCK (app->dock),
-													DOCK_PH_BOTTOM);
-	g_object_set (placeholder, "height", GINT_TO_POINTER((gint)(0.25 * height)),
-				  NULL);
-	placeholder = gdl_dock_get_placeholder_by_name (GDL_DOCK (app->dock),
-													DOCK_PH_LEFT);
-	g_object_set (placeholder, "width", GINT_TO_POINTER((gint)(0.25 * width)),
-				  NULL);
-	placeholder = gdl_dock_get_placeholder_by_name (GDL_DOCK (app->dock),
-													DOCK_PH_RIGHT);
-	g_object_set (placeholder, "width", GINT_TO_POINTER((gint)(0.25 * width)),
-				  NULL);
 }
 
 static void
@@ -848,8 +883,8 @@ anjuta_app_remove_value (AnjutaShell *shell, const char *name, GError **error)
 	*/
 	
 	if (app->values && g_hash_table_lookup_extended (app->values, name, 
-													 (gpointer*)&key,
-													 (gpointer*)&value)) {
+													 (gpointer)&key,
+													 (gpointer)&value)) {
 		g_signal_emit_by_name (app, "value_removed", name);
 		g_hash_table_remove (app->values, name);
 	}
@@ -893,6 +928,8 @@ on_widget_remove (GtkWidget *container, GtkWidget *widget, AnjutaApp *app)
 	dock_item = g_object_get_data (G_OBJECT (widget), "dockitem");
 	if (dock_item)
 	{
+		gchar* unique_name = g_object_get_data(G_OBJECT(dock_item), "unique_name");
+		g_free(unique_name);
 		g_signal_handlers_disconnect_by_func (G_OBJECT (dock_item),
 					G_CALLBACK (on_widget_remove), app);
 		gdl_dock_item_unbind (GDL_DOCK_ITEM(dock_item));
@@ -942,8 +979,6 @@ anjuta_app_add_widget (AnjutaShell *shell,
 	AnjutaApp *app;
 	GtkWidget *item;
 	GtkCheckMenuItem* menuitem;
-	GdlDockPlaceholder* placeholder;
-	const gchar *placeholder_name;
 
 	g_return_if_fail (ANJUTA_IS_APP (shell));
 	g_return_if_fail (GTK_IS_WIDGET (widget));
@@ -974,27 +1009,8 @@ anjuta_app_add_widget (AnjutaShell *shell,
 		item = gdl_dock_item_new_with_stock (name, title, stock_id,
 											 GDL_DOCK_ITEM_BEH_NORMAL);
 	gtk_container_add (GTK_CONTAINER (item), widget);
-	
-	if (placement != GDL_DOCK_FLOATING)
-	{
-		switch (placement)
-		{
-			case GDL_DOCK_TOP: placeholder_name = DOCK_PH_TOP; break;
-			case GDL_DOCK_BOTTOM: placeholder_name = DOCK_PH_BOTTOM; break;
-			case GDL_DOCK_LEFT: placeholder_name = DOCK_PH_LEFT; break;
-			case GDL_DOCK_RIGHT: placeholder_name = DOCK_PH_RIGHT; break;
-			default: placeholder_name = "ph_center";
-		}
-		
-		placeholder = gdl_dock_get_placeholder_by_name (GDL_DOCK (app->dock), 
-														placeholder_name);
-		gtk_container_add (GTK_CONTAINER (placeholder), GTK_WIDGET (item));
-	}
-	else
-	{
-        gdl_dock_add_item (GDL_DOCK (app->dock),
-                           GDL_DOCK_ITEM (item), GDL_DOCK_FLOATING);
-	}
+    gdl_dock_add_item (GDL_DOCK (app->dock),
+                       GDL_DOCK_ITEM (item), placement);
 	gtk_widget_show_all (item);
 	
 	/* Add toggle button for the widget */
@@ -1120,6 +1136,13 @@ anjuta_app_get_plugin_manager  (AnjutaShell *shell, GError **error)
 	return ANJUTA_APP (shell)->plugin_manager;
 }
 
+static AnjutaProfileManager *
+anjuta_app_get_profile_manager (AnjutaShell *shell, GError **error)
+{
+	g_return_val_if_fail (ANJUTA_IS_APP (shell), NULL);
+	return ANJUTA_APP (shell)->profile_manager;
+}
+
 static void
 anjuta_shell_iface_init (AnjutaShellIface *iface)
 {
@@ -1134,47 +1157,9 @@ anjuta_shell_iface_init (AnjutaShellIface *iface)
 	iface->get_ui = anjuta_app_get_ui;
 	iface->get_preferences = anjuta_app_get_preferences;
 	iface->get_plugin_manager = anjuta_app_get_plugin_manager;
+	iface->get_profile_manager = anjuta_app_get_profile_manager;
 }
 
 ANJUTA_TYPE_BEGIN(AnjutaApp, anjuta_app, GNOME_TYPE_APP);
 ANJUTA_TYPE_ADD_INTERFACE(anjuta_shell, ANJUTA_TYPE_SHELL);
 ANJUTA_TYPE_END;
-
-#if 0 /* FIXME: Implement progress bar in AnjutaShell */
-gboolean
-anjuta_app_progress_init (AnjutaApp *app, gchar * description,
-						  gdouble full_value,
-						  GnomeAppProgressCancelFunc cancel_cb,
-						  gpointer data)
-{
-	if (app->in_progress)
-		return FALSE;
-	app->in_progress = TRUE;
-	app->progress_value = 0.0;
-	app->progress_full_value = full_value;
-	app->progress_cancel_cb = cancel_cb;
-	app->progress_key =
-		gnome_app_progress_timeout (GNOME_APP (app),
-					    description,
-					    100,
-					    on_anjuta_progress_cb,
-					    on_anjuta_progress_cancel, data);
-	return TRUE;
-}
-
-void
-anjuta_app_progress_set (AnjutaApp *app, gdouble value)
-{
-	if (app->in_progress)
-		app->progress_value = value / app->progress_full_value;
-}
-
-void
-anjuta_app_progress_done (AnjutaApp *app, gchar * end_mesg)
-{
-	if (app->in_progress)
-		gnome_app_progress_done (app->progress_key);
-	anjuta_status (end_mesg);
-	app->in_progress = FALSE;
-}
-#endif
